@@ -6,8 +6,8 @@ from typing import Union
 
 from loguru import logger
 
-from aflowey import AsyncFlow
-from aflowey import F
+from aflowey.async_flow import AsyncFlow
+from aflowey.f import F
 from aflowey.functions import get_name
 from aflowey.functions import is_f0
 from aflowey.functions import is_side_effect
@@ -49,7 +49,8 @@ def check_and_run_step(
 ) -> Awaitable[Any]:
     if fn.is_coroutine_function:
         new_fn = async_wrap(fn)
-        return asyncio.create_task(new_fn(*args, **kwargs))  # type: ignore[call-arg]
+        # make it 3.6 compatible
+        return asyncio.get_event_loop().create_task(new_fn(*args, **kwargs))  # type: ignore[call-arg]
     if executor is None:
         new_fn = async_wrap(fn)
         return new_fn(*args, **kwargs)  # type: ignore[call-arg]
